summaryrefslogtreecommitdiffstats
path: root/extra/kde353/kkeyserver_x11.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 03:12:09 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 03:12:09 -0600
commitb7333cd4f3c45b30853f7a748ac43bb2fa820d41 (patch)
tree037656a0676d513cb895ba2caa84d451080e8fab /extra/kde353/kkeyserver_x11.h
parentd0e77a7577bcf1f4111244a44d3966bf14c2774d (diff)
downloadpytde-b7333cd4f3c45b30853f7a748ac43bb2fa820d41.tar.gz
pytde-b7333cd4f3c45b30853f7a748ac43bb2fa820d41.zip
Fix a number of kkeyserver problems
Diffstat (limited to 'extra/kde353/kkeyserver_x11.h')
-rw-r--r--extra/kde353/kkeyserver_x11.h82
1 files changed, 41 insertions, 41 deletions
diff --git a/extra/kde353/kkeyserver_x11.h b/extra/kde353/kkeyserver_x11.h
index daecca4..ce3fa2f 100644
--- a/extra/kde353/kkeyserver_x11.h
+++ b/extra/kde353/kkeyserver_x11.h
@@ -68,12 +68,12 @@ namespace KKeyServer
{ init( s ); }
/**
* Initializes the symbol with the given TQt key code.
* @param keyTQt the qt key code
* @return true if successful, false otherwise
- * @see TQt::Key
+ * @see Qt::Key
*/
- bool initTQt( int keyTQt );
+ bool initQt( int keyQt );
/**
* Initializes the key with the given string description.
@@ -101,10 +101,10 @@ namespace KKeyServer
TQString toString() const;
/**
- * Returns the mods that are retquired for this symbol as
- * ORed KKey::ModFlag's. For example, Break retquires a
+ * Returns the mods that are required for this symbol as
+ * ORed KKey::ModFlag's. For example, Break requires a
* Ctrl to be valid.
- * @return the retquired KKey::ModFlag's
+ * @return the required KKey::ModFlag's
* @see KKey::ModFlag
*/
uint getModsRequired() const;
@@ -136,7 +136,7 @@ namespace KKeyServer
*/
struct TDECORE_EXPORT Key
{
- /// Code for native Keys in TQt
+ /// Code for native Keys in Qt
enum { CODE_FOR_QT = 256 };
/// The code of the key
@@ -151,18 +151,18 @@ namespace KKeyServer
/**
* Initializes the key with a KKey.
* @param key the key to get the data from
* @param bTQt true to take the TQt keycode, false
* for the native key code
- * @see TQt::Key
+ * @see Qt::Key
* @see KKeyNative
*/
- bool init( const KKey& key, bool bTQt );
+ bool init( const KKey& key, bool bQt );
/**
* Checks whether the key code is a native code.
* @return true if native code of the window system,
- * false if it is a TQt keycode
- * @see TQt::Key
+ * false if it is a Qt keycode
+ * @see Qt::Key
* @see KKeyNative
*/
bool isNative() const { return m_code != CODE_FOR_QT; }
@@ -193,10 +193,10 @@ namespace KKeyServer
/**
* Sets the qt key code.
* @param keyTQt the qt key code
*/
- void setKeycodeTQt( int keyTQt )
- { m_code = CODE_FOR_QT; m_sym = keyTQt; }
+ void setKeycodeQt( int keyQt )
+ { m_code = CODE_FOR_QT; m_sym = keyQt; }
/**
* Initializes this key with a KKeyNative.
@@ -250,7 +250,7 @@ namespace KKeyServer
Variations() { m_nVariations = 0; }
- void init( const KKey&, bool bTQt );
+ void init( const KKey&, bool bQt );
uint count() const { return m_nVariations; }
const Key& key( uint i ) const { return m_rgkey[i]; }
@@ -346,47 +346,47 @@ namespace KKeyServer
TDECORE_EXPORT uint accelModMaskX();
/**
- * Extracts the symbol from the given TQt key and
+ * Extracts the symbol from the given Qt key and
* converts it to a symbol.
* @param keyTQt the qt key code
* @param sym if successful, the symbol will be written here
* @return true if successful, false otherwise
- * @see TQt::Key
+ * @see Qt::Key
* @see Sym
*/
- TDECORE_EXPORT bool keyTQtToSym( int keyTQt, uint& sym );
+ TDECORE_EXPORT bool keyQtToSym( int keyQt, uint& sym );
/**
- * Extracts the modifiers from the given TQt key and
+ * Extracts the modifiers from the given Qt key and
* converts them in a mask of ORed KKey::ModFlag modifiers.
* @param keyTQt the qt key code
* @param mod if successful, the modifiers will be written here
* @return true if successful, false otherwise
- * @see TQt::Key
+ * @see Qt::Key
*/
- TDECORE_EXPORT bool keyTQtToMod( int keyTQt, uint& mod );
+ TDECORE_EXPORT bool keyQtToMod( int keyQt, uint& mod );
/**
- * Converts the given symbol to a TQt key code.
+ * Converts the given symbol to a Qt key code.
* @param sym the symbol
* @param keyTQt if successful, the qt key code will be written here
* @return true if successful, false otherwise
- * @see TQt::Key
+ * @see Qt::Key
* @see Sym
*/
- TDECORE_EXPORT bool symToKeyTQt( uint sym, int& keyTQt );
+ TDECORE_EXPORT bool symToKeyQt( uint sym, int& keyQt );
/**
* Converts the mask of ORed KKey::ModFlag modifiers to
- * a mask of ORed TQt key code modifiers.
+ * a mask of ORed Qt key code modifiers.
* @param mod the mask of KKey::ModFlag modifiers
* @param modTQt the mask of TQt key code modifiers will be written here,
* if successful
* @return true if successful, false otherwise
- * @see TQt::Key
+ * @see Qt::Key
* @see KKey
*/
- TDECORE_EXPORT bool modToModTQt( uint mod, int& modTQt );
+ TDECORE_EXPORT bool modToModQt( uint mod, int& modQt );
/**
* Converts the mask of ORed KKey::ModFlag modifiers to
@@ -401,20 +401,20 @@ namespace KKeyServer
/**
* Converts the mask of ORed X11 modifiers to
- * a mask of ORed TQt key code modifiers.
+ * a mask of ORed Qt key code modifiers.
* @param modX the mask of X11 modifiers
* @param modTQt the mask of TQt key code modifiers will be written here
* if successful
* @return true if successful, false otherwise
- * @see TQt::Key
+ * @see Qt::Key
*/
//wrapped for win32
- TDECORE_EXPORT bool modXToModTQt( uint modX, int& modTQt );
+ TDECORE_EXPORT bool modXToModQt( uint modX, int& modQt );
/**
- * Converts the TQt-compatible button state to x11 modifier.
+ * Converts the Qt-compatible button state to x11 modifier.
*/
- TDECORE_EXPORT int qtButtonStateToMod( TQt::ButtonState s );
+ TDECORE_EXPORT int qtButtonStateToMod( TQ_ButtonState s );
/**
* Converts the mask of ORed X11 modifiers to
@@ -435,7 +435,7 @@ namespace KKeyServer
* @param modX the mask of ORed X11 modifiers
* @param symX if successful, the X11 symbol will be written here
* @return true if successful, false otherwise
- * @see TQt::Key
+ * @see Qt::Key
* @see Sym
*/
TDECORE_EXPORT bool codeXToSym( uchar codeX, uint modX, uint& symX );
@@ -471,7 +471,7 @@ namespace KKeyServer
* @internal
* Unimplemented?
*/
- TDECORE_EXPORT void keyTQtToKeyX( uint keyCombTQt, unsigned char *pKeyCodeX, uint *pKeySymX, uint *pKeyModX );
+ TDECORE_EXPORT void keyQtToKeyX( uint keyCombQt, unsigned char *pKeyCodeX, uint *pKeySymX, uint *pKeyModX );
}
#endif // !_KKEYSERVER_X11_H
@@ -68,12 +68,12 @@ namespace KKeyServer
{ init( s ); }
/**
- * Initializes the symbol with the given TQt key code.
- * @param keyTQt the qt key code
+ * Initializes the symbol with the given Qt key code.
+ * @param keyQt the qt key code
* @return true if successful, false otherwise
@@ -151,18 +151,18 @@ namespace KKeyServer
* Initializes the key with a KKey.
* @param key the key to get the data from
- * @param bTQt true to take the TQt keycode, false
+ * @param bQt true to take the Qt keycode, false
* for the native key code
@@ -193,10 +193,10 @@ namespace KKeyServer
/**
* Sets the qt key code.
- * @param keyTQt the qt key code
+ * @param keyQt the qt key code
*/
@@ -346,47 +346,47 @@ namespace KKeyServer
* converts it to a symbol.
- * @param keyTQt the qt key code
+ * @param keyQt the qt key code
* @param sym if successful, the symbol will be written here
* @return true if successful, false otherwise
@@ -346,47 +346,47 @@ namespace KKeyServer
* converts them in a mask of ORed KKey::ModFlag modifiers.
- * @param keyTQt the qt key code
+ * @param keyQt the qt key code
* @param mod if successful, the modifiers will be written here
* @return true if successful, false otherwise
@@ -346,47 +346,47 @@ namespace KKeyServer
* @param sym the symbol
- * @param keyTQt if successful, the qt key code will be written here
+ * @param keyQt if successful, the qt key code will be written here
* @return true if successful, false otherwise
@@ -346,47 +346,47 @@ namespace KKeyServer
* @param mod the mask of KKey::ModFlag modifiers
- * @param modTQt the mask of TQt key code modifiers will be written here,
+ * @param modQt the mask of Qt key code modifiers will be written here,
* if successful
* @return true if successful, false otherwise
@@ -401,20 +401,20 @@ namespace KKeyServer
* @param modX the mask of X11 modifiers
- * @param modTQt the mask of TQt key code modifiers will be written here
+ * @param modQt the mask of Qt key code modifiers will be written here
* if successful
* @return true if successful, false otherwise